yt.visualization.fixed\_resolution module
=========================================

.. automodule:: yt.visualization.fixed_resolution
   :members:
   :undoc-members:
   :inherited-members:
   :show-inheritance:
